@@ -41,6 +41,7 @@
 #include "logmainview.h"
 #include "quickfind.h"
 #include "quickfindpattern.h"
+#include "overview.h"
 
 
 LineChunk::LineChunk( int first_col, int last_col, ChunkType type )
@@ -166,12 +167,14 @@ void DigitsBuffer::timerEvent( QTimerEvent* event )
     }
 }
 
-
+// Graphic parameters
 
 // Looks better with an odd value
 const int AbstractLogView::bulletLineX_ = 11;
 const int AbstractLogView::leftMarginPx_ = bulletLineX_ + 2;
 
+const int AbstractLogView::OVERVIEW_WIDTH = 27;
+
 AbstractLogView::AbstractLogView(const AbstractLogData* newLogData,
         const QuickFindPattern* const quickFindPattern, QWidget* parent) :
     QAbstractScrollArea( parent ),
@@ -180,27 +183,32 @@ AbstractLogView::AbstractLogView(const AbstractLogData* newLogData,
     autoScrollTimer_(),
     selection_(),
     quickFindPattern_( quickFindPattern ),
-    quickFind_( newLogData, &selection_, quickFindPattern )
+    quickFind_( newLogData, &selection_, quickFindPattern ),
+    overviewWidget_( this )
 {
-    logData           = newLogData;
-
-    // Create the viewport QWidget
-    setViewport(0);
-    setAttribute(Qt::WA_StaticContents);  // Does it work?
+    logData = newLogData;
 
     followMode_ = false;
 
     selectionStarted_ = false;
+    markingClickInitiated_ = false;
 
     firstLine = 0;
     lastLine = 0;
     firstCol = 0;
 
+    overview_ = NULL;
+
     // Fonts
     useFixedFont_ = false;
     charWidth_ = 1;
     charHeight_ = 1;
 
+    // Create the viewport QWidget
+    setViewport( 0 );
+
+    setAttribute( Qt::WA_StaticContents );  // Does it work?
+
     // Signals
     connect( quickFindPattern_, SIGNAL( patternUpdated() ),
             this, SLOT ( handlePatternUpdated() ) );
@@ -210,6 +218,10 @@ AbstractLogView::AbstractLogView(const AbstractLogData* newLogData,
             this, SIGNAL( notifyQuickFind( const QString& ) ) );
     connect( &quickFind_, SIGNAL( clearNotification() ),
             this, SIGNAL( clearQuickFindNotification() ) );
+    connect( &overviewWidget_, SIGNAL( lineClicked ( int ) ),
+            this, SIGNAL( followDisabled() ) );
+    connect( &overviewWidget_, SIGNAL( lineClicked ( int ) ),
+            this, SLOT( jumpToLine( int ) ) );
 }
 
 AbstractLogView::~AbstractLogView()
@@ -239,16 +251,26 @@ void AbstractLogView::mousePressEvent( QMouseEvent* mouseEvent )
     if ( mouseEvent->button() == Qt::LeftButton )
     {
         int line = convertCoordToLine( mouseEvent->y() );
-        if ( line < logData->getNbLine() ) {
-            selection_.selectLine( line );
-            emit updateLineNumber( line );
-            emit newSelection( line );
-        }
 
-        // Remember the click in case we're starting a selection
-        selectionStarted_ = true;
-        selectionStartPos_ = convertCoordToFilePos( mouseEvent->pos() );
-        selectionCurrentEndPos_ = selectionStartPos_;
+        if ( mouseEvent->x() < leftMarginPx_ ) {
+            // Mark a line if it is clicked in the left margin
+            // (only if click and release in the same area)
+            markingClickInitiated_ = true;
+            markingClickLine_ = line;
+        }
+        else {
+            // Select the line, and start a selection
+            if ( line < logData->getNbLine() ) {
+                selection_.selectLine( line );
+                emit updateLineNumber( line );
+                emit newSelection( line );
+            }
+
+            // Remember the click in case we're starting a selection
+            selectionStarted_ = true;
+            selectionStartPos_ = convertCoordToFilePos( mouseEvent->pos() );
+            selectionCurrentEndPos_ = selectionStartPos_;
+        }
     }
 }
 
@@ -300,12 +322,20 @@ void AbstractLogView::mouseMoveEvent( QMouseEvent* mouseEvent )
     }
 }
 
-void AbstractLogView::mouseReleaseEvent( QMouseEvent* )
+void AbstractLogView::mouseReleaseEvent( QMouseEvent* mouseEvent )
 {
-    selectionStarted_ = false;
-    if ( autoScrollTimer_.isActive() )
-        autoScrollTimer_.stop();
-    updateGlobalSelection();
+    if ( markingClickInitiated_ ) {
+        markingClickInitiated_ = false;
+        int line = convertCoordToLine( mouseEvent->y() );
+        if ( line == markingClickLine_ )
+            emit markLine( line );
+    }
+    else {
+        selectionStarted_ = false;
+        if ( autoScrollTimer_.isActive() )
+            autoScrollTimer_.stop();
+        updateGlobalSelection();
+    }
 }
 
 void AbstractLogView::mouseDoubleClickEvent( QMouseEvent* mouseEvent )
@@ -480,6 +510,11 @@ void AbstractLogView::scrollContentsBy( int dx, int dy )
     firstCol  = (firstCol - dx) > 0 ? firstCol - dx : 0;
     lastLine = qMin( logData->getNbLine(), firstLine + getNbVisibleLines() );
 
+    // Update the overview if we have one
+    if ( overview_ != NULL )
+        overview_->updateCurrentPosition( firstLine, lastLine );
+
+    // Redraw
     update();
 }
 
@@ -506,8 +541,9 @@ void AbstractLogView::paintEvent( QPaintEvent* paintEvent )
         const FilterSet& filterSet = Persistent<FilterSet>( "filterSet" );
         QColor foreColor, backColor;
 
-        const QBrush normalBulletBrush = QBrush( Qt::white );
-        const QBrush matchBulletBrush = QBrush( Qt::red );
+        static const QBrush normalBulletBrush = QBrush( Qt::white );
+        static const QBrush matchBulletBrush = QBrush( Qt::red );
+        static const QBrush markBrush = QBrush( "dodgerblue" );
 
         // First check the lines to be drawn are within range (might not be the case if
         // the file has just changed)
@@ -630,21 +666,49 @@ void AbstractLogView::paintEvent( QPaintEvent* paintEvent )
             }
 
             // Then draw the bullet
-            const int circleSize = 3;
-
-            if ( isLineMatching( i ) )
-                painter.setBrush( matchBulletBrush );
-            else
-                painter.setBrush( normalBulletBrush );
             painter.setPen( palette.color( QPalette::Text ) );
-            painter.drawEllipse( bulletLineX_/2 - circleSize,
-                    yPos + (fontHeight / 2) - circleSize,
-                    circleSize * 2, circleSize * 2 );
-        }
+            const int circleSize = 3;
+            const int arrowHeight = 4;
+            const int middleXLine = bulletLineX_ / 2;
+            const int middleYLine = yPos + (fontHeight / 2);
+
+            const LineType line_type = lineType( i );
+            if ( line_type == Marked ) {
+                // A pretty arrow if the line is marked
+                const QPoint points[7] = {
+                    QPoint(1, middleYLine - 2),
+                    QPoint(middleXLine, middleYLine - 2),
+                    QPoint(middleXLine, middleYLine - arrowHeight),
+                    QPoint(bulletLineX_ - 2, middleYLine),
+                    QPoint(middleXLine, middleYLine + arrowHeight),
+                    QPoint(middleXLine, middleYLine + 2),
+                    QPoint(1, middleYLine + 2 ),
+                };
+
+                painter.setBrush( markBrush );
+                painter.drawPolygon( points, 7 );
+            }
+            else {
+                if ( lineType( i ) == Match )
+                    painter.setBrush( matchBulletBrush );
+                else
+                    painter.setBrush( normalBulletBrush );
+                painter.drawEllipse( middleXLine - circleSize,
+                        middleYLine - circleSize,
+                        circleSize * 2, circleSize * 2 );
+            }
+        } // For each line
     }
     LOG(logDEBUG4) << "End of repaint";
 }
 
+void AbstractLogView::setOverview( Overview* overview )
+{
+    overview_ = overview;
+    refreshOverview();
+    overviewWidget_.setOverview( overview );
+}
+
 void AbstractLogView::searchNext()
 {
     searchForward();
@@ -686,6 +750,19 @@ void AbstractLogView::followSet( bool checked )
         jumpToBottom();
 }
 
+void AbstractLogView::refreshOverview()
+{
+    // Create space for the Overview if needed
+    if ( ( getOverview() != NULL ) && getOverview()->isVisible() ) {
+        setViewportMargins( 0, 0, OVERVIEW_WIDTH, 0 );
+        overviewWidget_.show();
+    }
+    else {
+        setViewportMargins( 0, 0, 0, 0 );
+        overviewWidget_.hide();
+    }
+}
+
 // Reset the QuickFind when the pattern is changed.
 void AbstractLogView::handlePatternUpdated()
 {
@@ -701,6 +778,8 @@ void AbstractLogView::handlePatternUpdated()
 
 void AbstractLogView::updateData()
 {
+    LOG(logDEBUG) << "AbstractLogView::updateData";
+
     // Check the top Line is within range
     if ( firstLine >= logData->getNbLine() ) {
         firstLine = 0;
@@ -726,6 +805,10 @@ void AbstractLogView::updateData()
     if ( followMode_ )
         jumpToBottom();
 
+    // Update the overview if we have one
+    if ( overview_ != NULL )
+        overview_->updateCurrentPosition( firstLine, lastLine );
+
     // Repaint!
     update();
 }
@@ -754,10 +837,14 @@ void AbstractLogView::updateDisplaySize()
 
     const int hScrollMaxValue = ( logData->getMaxLength() - getNbVisibleCols() + 1 ) > 0 ?
         ( logData->getMaxLength() - getNbVisibleCols() + 1 ) : 0;
-    LOG(logDEBUG) << "getMaxLength=" << logData->getMaxLength();
-    LOG(logDEBUG) << "getNbVisibleCols=" << getNbVisibleCols();
-    LOG(logDEBUG) << "hScrollMaxValue=" << hScrollMaxValue;
-    horizontalScrollBar()->setRange( 0,  hScrollMaxValue );
+    horizontalScrollBar()->setRange( 0, hScrollMaxValue );
+
+    LOG(logDEBUG) << "viewport.width()=" << viewport()->width();
+    LOG(logDEBUG) << "viewport.height()=" << viewport()->height();
+    LOG(logDEBUG) << "width()=" << width();
+    LOG(logDEBUG) << "height()=" << height();
+    overviewWidget_.setGeometry( viewport()->width() + 2, 1,
+            OVERVIEW_WIDTH - 1, viewport()->height() );
 }
 
 int AbstractLogView::getTopLine() const
@@ -778,6 +865,19 @@ void AbstractLogView::selectAndDisplayLine( int line )
     emit updateLineNumber( line );
 }
 
+// The difference between this function and displayLine() is quite
+// subtle: this one always jump, even if the line passed is visible.
+void AbstractLogView::jumpToLine( int line )
+{
+    // Put the selected line in the middle if possible
+    int newTopLine = line - ( getNbVisibleLines() / 2 );
+    if ( newTopLine < 0 )
+        newTopLine = 0;
+
+    // This will also trigger a scrollContents event
+    verticalScrollBar()->setValue( newTopLine );
+}
+
 //
 // Private functions
 //
@@ -851,13 +951,7 @@ void AbstractLogView::displayLine( int line )
         // ... don't scroll and just repaint
         update();
     } else {
-        // Put the selected line in the middle if possible
-        int newTopLine = line - ( getNbVisibleLines() / 2 );
-        if ( newTopLine < 0 )
-            newTopLine = 0;
-
-        // This will also trigger a scrollContents event
-        verticalScrollBar()->setValue( newTopLine );
+        jumpToLine( line );
     }
 }
 
