@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009, 2010 Nicolas Bonnefon and other contributors
+ * Copyright (C) 2009, 2010, 2011 Nicolas Bonnefon and other contributors
  *
  * This file is part of glogg.
  *
@@ -26,6 +26,7 @@
 #include "abstractlogdata.h"
 #include "selection.h"
 #include "quickfind.h"
+#include "overviewwidget.h"
 
 class LineChunk
 {
@@ -129,6 +130,7 @@ class DigitsBuffer : public QObject
     QBasicTimer timer_;
 };
 
+class Overview;
 
 // Base class representing the log view widget.
 // It can be either the top (full) or bottom (filtered) view.
@@ -168,8 +170,14 @@ class AbstractLogView : public QAbstractScrollArea
     void wheelEvent( QWheelEvent* wheelEvent );
 
     // Must be implemented to return wether the line number is
-    // a match or not (used for coloured bullets)
-    virtual bool isLineMatching( int lineNumber ) = 0;
+    // a match, a mark or just a normal line (used for coloured bullets)
+    enum LineType { Normal, Marked, Match };
+    virtual LineType lineType( int lineNumber ) const = 0;
+
+    // Get the overview associated with this view, or NULL if there is none
+    Overview* getOverview() const { return overview_; }
+    // Set the Overview
+    void setOverview( Overview* overview );
 
   signals:
     // Sent when a new line has been selected by the user.
@@ -184,6 +192,9 @@ class AbstractLogView : public QAbstractScrollArea
     void notifyQuickFind( const QString& message );
     // Sent up when quickFind wants to clear the notification.
     void clearQuickFindNotification();
+    // Sent when the view ask for a line to be marked
+    // (click in the left margin).
+    void markLine( qint64 line );
 
   public slots:
     // Makes the widget select and display the passed line.
@@ -195,9 +206,17 @@ class AbstractLogView : public QAbstractScrollArea
     // Use the current QFP to go and select the previous match.
     void searchBackward();
 
-    // Signals the follow mode has been enabled
+    // Signals the follow mode has been enabled.
     void followSet( bool checked );
 
+    // Signal the on/off status of the overview has been changed.
+    void refreshOverview();
+
+    // Make the view jump to the specified line, regardless of weither it
+    // is on the screen or not.
+    // (does NOT emit followDisabled() )
+    void jumpToLine( int line );
+
   private slots:
     void handlePatternUpdated();
 
@@ -205,6 +224,7 @@ class AbstractLogView : public QAbstractScrollArea
     // Constants
     static const int bulletLineX_;
     static const int leftMarginPx_;
+    static const int OVERVIEW_WIDTH;
 
     // Digits buffer
     DigitsBuffer digitsBuffer_;
@@ -215,6 +235,9 @@ class AbstractLogView : public QAbstractScrollArea
     // Pointer to the CrawlerWidget's data set
     const AbstractLogData* logData;
 
+    // Pointer to the Overview object
+    Overview* overview_;
+
     bool selectionStarted_;
     // Start of the selection (characters)
     QPoint selectionStartPos_;
@@ -222,6 +245,10 @@ class AbstractLogView : public QAbstractScrollArea
     QPoint selectionCurrentEndPos_;
     QBasicTimer autoScrollTimer_;
 
+    // Marks (left margin click)
+    bool markingClickInitiated_;
+    qint64 markingClickLine_;
+
     Selection selection_;
     qint64 firstLine;
     qint64 lastLine;
@@ -237,6 +264,8 @@ class AbstractLogView : public QAbstractScrollArea
     // Our own QuickFind object
     QuickFind quickFind_;
 
+    OverviewWidget overviewWidget_;
+
     int getNbVisibleLines() const;
     int getNbVisibleCols() const;
     void convertCoordToFilePos( const QPoint& pos,
