@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009, 2010 Nicolas Bonnefon and other contributors
+ * Copyright (C) 2009, 2010, 2011, 2012 Nicolas Bonnefon and other contributors
  *
  * This file is part of glogg.
  *
@@ -33,6 +33,11 @@
 
 #include "crawlerwidget.h"
 
+#include "quickfindpattern.h"
+#include "overview.h"
+#include "infoline.h"
+#include "savedsearches.h"
+#include "quickfindwidget.h"
 #include "persistentinfo.h"
 #include "configuration.h"
 
@@ -53,8 +58,11 @@ CrawlerWidget::CrawlerWidget(SavedSearches* searches, QWidget *parent)
     // This is the confirmed pattern used by n/N and coloured in yellow.
     quickFindPattern_ = new QuickFindPattern();
 
+    // The matches overview
+    overview_ = new Overview();
+
     // The views
-    logMainView  = new LogMainView( logData_, quickFindPattern_ );
+    logMainView  = new LogMainView( logData_, quickFindPattern_, overview_ );
     bottomWindow = new QWidget;
     filteredView = new FilteredView( logFilteredData_, quickFindPattern_ );
 
@@ -143,6 +151,10 @@ CrawlerWidget::CrawlerWidget(SavedSearches* searches, QWidget *parent)
             filteredView, SLOT( update() ) );
     connect(logMainView, SIGNAL( updateLineNumber( int ) ),
             this, SIGNAL( updateLineNumber( int ) ) );
+    connect(logMainView, SIGNAL( markLine( qint64 ) ),
+            this, SLOT( markLineFromMain( qint64 ) ) );
+    connect(filteredView, SIGNAL( markLine( qint64 ) ),
+            this, SLOT( markLineFromFiltered( qint64 ) ) );
 
     // Follow option (up and down)
     connect(this, SIGNAL( followSet( bool ) ),
@@ -201,10 +213,11 @@ bool CrawlerWidget::readFile( const QString& fileName, int )
         // First we cancel any in progress search and loading
         stopLoading();
 
-        // The file exist, so we invalidate the search
+        // The file exist, so we invalidate the search, remove all marks
         // and redraw the screen.
-        logData_->attachFile( fileName );
         replaceCurrentSearch( "" );
+        logFilteredData_->clearMarks();
+        logData_->attachFile( fileName );
         logMainView->updateData();
 
         // Forbid starting a search when loading in progress
@@ -319,6 +332,9 @@ void CrawlerWidget::updateFilteredView( int nbMatches, int progress )
     // Recompute the content of the filtered window.
     filteredView->updateData();
 
+    // Update the match overview
+    overview_->updateData( logData_->getNbLine() );
+
     // Also update the top window for the coloured bullets.
     update();
 }
@@ -329,6 +345,42 @@ void CrawlerWidget::jumpToMatchingLine(int filteredLineNb)
     logMainView->selectAndDisplayLine(mainViewLine);  // FIXME: should be done with a signal.
 }
 
+void CrawlerWidget::markLineFromMain( qint64 line )
+{
+    if ( logFilteredData_->isLineMarked( line ) )
+        logFilteredData_->deleteMark( line );
+    else
+        logFilteredData_->addMark( line );
+
+    // Recompute the content of the filtered window.
+    filteredView->updateData();
+
+    // Update the match overview
+    overview_->updateData( logData_->getNbLine() );
+
+    // Also update the top window for the coloured bullets.
+    update();
+}
+
+void CrawlerWidget::markLineFromFiltered( qint64 line )
+{
+    qint64 line_in_file = logFilteredData_->getMatchingLineNumber( line );
+    if ( logFilteredData_->filteredLineTypeByIndex( line )
+            == LogFilteredData::Mark )
+        logFilteredData_->deleteMark( line_in_file );
+    else
+        logFilteredData_->addMark( line_in_file );
+
+    // Recompute the content of the filtered window.
+    filteredView->updateData();
+
+    // Update the match overview
+    overview_->updateData( logData_->getNbLine() );
+
+    // Also update the top window for the coloured bullets.
+    update();
+}
+
 void CrawlerWidget::applyConfiguration()
 {
     Configuration& config = Persistent<Configuration>( "settings" );
@@ -339,6 +391,9 @@ void CrawlerWidget::applyConfiguration()
     logMainView->setFont(font);
     filteredView->setFont(font);
 
+    overview_->setVisible( config.isOverviewVisible() );
+    logMainView->refreshOverview();
+
     logMainView->updateDisplaySize();
     logMainView->update();
     filteredView->updateDisplaySize();
@@ -350,9 +405,14 @@ void CrawlerWidget::applyConfiguration()
 
 void CrawlerWidget::loadingFinishedHandler( bool success )
 {
+    // We need to refresh the main window because the view lines on the
+    // overview have probably changed.
+    overview_->updateData( logData_->getNbLine() );
+
     // FIXME, handle topLine
     // logMainView->updateData( logData_, topLine );
     logMainView->updateData();
+
     // searchButton->setEnabled( true );
 
     // See if we need to auto-refresh the search
@@ -367,12 +427,16 @@ void CrawlerWidget::loadingFinishedHandler( bool success )
 void CrawlerWidget::fileChangedHandler( LogData::MonitoredFileStatus status )
 {
     // Handle the case where the file has been truncated
-    if ( ( status == LogData::Truncated ) &&
-         !( searchInfoLine->text().isEmpty()) ) {
-        logFilteredData_->clearSearch();
-        filteredView->updateData();
-        searchState_.truncateFile();
-        printSearchInfoMessage();
+    if ( status == LogData::Truncated ) {
+        // Clear all marks (TODO offer the option to keep them)
+        logFilteredData_->clearMarks();
+        if ( ! searchInfoLine->text().isEmpty() ) {
+            // Invalidate the search
+            logFilteredData_->clearSearch();
+            filteredView->updateData();
+            searchState_.truncateFile();
+            printSearchInfoMessage();
+        }
     }
 }
 
@@ -438,14 +502,14 @@ void CrawlerWidget::searchBackward()
 void CrawlerWidget::searchRefreshChangedHandler( int state )
 {
     searchState_.setAutorefresh( state == Qt::Checked );
-    printSearchInfoMessage( logFilteredData_->getNbLine() );
+    printSearchInfoMessage( logFilteredData_->getNbMatches() );
 }
 
 void CrawlerWidget::searchTextChangeHandler()
 {
     // We suspend auto-refresh
     searchState_.changeExpression();
-    printSearchInfoMessage( logFilteredData_->getNbLine() );
+    printSearchInfoMessage( logFilteredData_->getNbMatches() );
 }
 
 //
@@ -456,7 +520,7 @@ void CrawlerWidget::searchTextChangeHandler()
 // used one and destroy the old one.
 void CrawlerWidget::replaceCurrentSearch( const QString& searchText )
 {
-    // Interrupt the searCh if it's ongoing
+    // Interrupt the search if it's ongoing
     logFilteredData_->interruptSearch();
 
     // We have to wait for the last search update (100%)
@@ -512,7 +576,8 @@ void CrawlerWidget::replaceCurrentSearch( const QString& searchText )
             searchInfoLine->setPalette( errorPalette );
             searchInfoLine->setText( errorMessage );
         }
-    } else {
+    }
+    else {
         logFilteredData_->clearSearch();
         filteredView->updateData();
         searchState_.resetState();
