@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009, 2010 Nicolas Bonnefon and other contributors
+ * Copyright (C) 2009, 2010, 2011 Nicolas Bonnefon and other contributors
  *
  * This file is part of glogg.
  *
@@ -27,17 +27,20 @@
 #include <QToolButton>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
+#include <QLabel>
 
 #include "logmainview.h"
 #include "filteredview.h"
-#include "savedsearches.h"
-#include "infoline.h"
-#include "quickfindpattern.h"
-#include "quickfindwidget.h"
 
 #include "logdata.h"
 #include "logfiltereddata.h"
 
+class InfoLine;
+class QuickFindPattern;
+class QuickFindWidget;
+class SavedSearches;
+class Overview;
+
 // Implements the central widget of the application.
 // It includes both windows, the search line, the info
 // lines and various buttons.
@@ -92,6 +95,10 @@ class CrawlerWidget : public QSplitter
     // Called when a new line has been selected in the filtered view,
     // to instruct the main view to jump to the matching line.
     void jumpToMatchingLine( int filteredLineNb );
+    // Mark a line that has been clicked on the main (top) view.
+    void markLineFromMain( qint64 line );
+    // Mark a line that has been clicked on the filtered (bottom) view.
+    void markLineFromFiltered( qint64 line );
 
     void loadingFinishedHandler( bool success );
     // Manages the info lines to inform the user the file has changed.
@@ -194,6 +201,9 @@ class CrawlerWidget : public QSplitter
 
     // Search state (for auto-refresh and truncation)
     SearchState     searchState_;
+
+    // Matches overview
+    Overview*       overview_;
 };
 
 #endif
