@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009, 2010 Nicolas Bonnefon and other contributors
+ * Copyright (C) 2009, 2010, 2011 Nicolas Bonnefon and other contributors
  *
  * This file is part of glogg.
  *
@@ -29,6 +29,7 @@ class LogMainView : public AbstractLogView
   public:
     LogMainView( const LogData* newLogData,
             const QuickFindPattern* const quickFindPattern,
+            Overview* overview = NULL,
             QWidget* parent = 0 );
 
     // Configure the view to use the passed filtered list
@@ -38,7 +39,7 @@ class LogMainView : public AbstractLogView
 
   protected:
     // Implements the virtual function
-    bool isLineMatching( int lineNumber );
+    virtual LineType lineType( int lineNumber ) const;
 
   private:
     LogFilteredData* filteredData_;
