@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009, 2010 Nicolas Bonnefon and other contributors
+ * Copyright (C) 2009, 2010, 2011 Nicolas Bonnefon and other contributors
  *
  * This file is part of glogg.
  *
@@ -28,13 +28,13 @@
 
 #include "mainwindow.h"
 
-#include "version.h"
 #include "sessioninfo.h"
 #include "recentfiles.h"
 #include "crawlerwidget.h"
 #include "filtersdialog.h"
 #include "optionsdialog.h"
 #include "persistentinfo.h"
+#include "savedsearches.h"
 
 MainWindow::MainWindow() :
     recentFiles( Persistent<RecentFiles>( "recentFiles" ) ), mainIcon_()
@@ -112,6 +112,8 @@ void MainWindow::createCrawler()
 // Menu actions
 void MainWindow::createActions()
 {
+    Configuration& config = Persistent<Configuration>( "settings" );
+
     openAction = new QAction(tr("&Open..."), this);
     openAction->setShortcut(QKeySequence::Open);
     openAction->setIcon( QIcon(":/images/open16.png") );
@@ -142,6 +144,12 @@ void MainWindow::createActions()
     connect( findAction, SIGNAL(triggered()),
             this, SLOT( find() ) );
 
+    overviewVisibleAction = new QAction( tr("Matches overview"), this );
+    overviewVisibleAction->setCheckable( true );
+    overviewVisibleAction->setChecked( config.isOverviewVisible() );
+    connect( overviewVisibleAction, SIGNAL( toggled( bool ) ),
+            this, SLOT( toggleOverviewVisibility( bool )) );
+
     followAction = new QAction( tr("&Follow File"), this );
     followAction->setShortcut(Qt::Key_F);
     followAction->setCheckable(true);
@@ -189,6 +197,8 @@ void MainWindow::createMenus()
     editMenu->addAction( findAction );
 
     viewMenu = menuBar()->addMenu( tr("&View") );
+    viewMenu->addAction( overviewVisibleAction );
+    viewMenu->addSeparator();
     viewMenu->addAction( followAction );
     viewMenu->addSeparator();
     viewMenu->addAction( reloadAction );
@@ -319,6 +329,15 @@ void MainWindow::aboutQt()
 {
 }
 
+void MainWindow::toggleOverviewVisibility( bool isVisible )
+{
+    Configuration& config = Persistent<Configuration>( "settings" );
+
+    config.setOverviewVisible( isVisible );
+
+    emit optionsChanged();
+}
+
 void MainWindow::disableFollow()
 {
     followAction->setChecked( false );
