@@ -22,10 +22,11 @@
 // current search pattern, once it has been confirmed (return pressed),
 // it can be asked to return the matches in a specific string.
 
-#include "configuration.h"
-
 #include "quickfindpattern.h"
 
+#include "persistentinfo.h"
+#include "configuration.h"
+
 QuickFindPattern::QuickFindPattern() : QObject(), regexp_()
 {
     active_ = false;
@@ -35,7 +36,7 @@ void QuickFindPattern::changeSearchPattern( const QString& pattern )
 {
     // Determine the type of regexp depending on the config
     QRegExp::PatternSyntax syntax;
-    switch ( Config().quickfindRegexpType() ) {
+    switch ( Persistent<Configuration>( "settings" ).quickfindRegexpType() ) {
         case Wildcard:
             syntax = QRegExp::Wildcard;
             break;
